@@ -269,6 +269,7 @@ private:
      * Get informations from the proxy node
      * @return the JSON returned by the proxy
      */
+    struct InfoState;
     void getProxyInfos();
     void onProxyInfos(const Json::Value& val, sa_family_t family);
     SockAddr parsePublicAddress(const Json::Value& val);
@@ -300,7 +301,7 @@ private:
     std::string serverHost_;
     std::string pushClientId_;
 
-    std::atomic_flag ongoingStatusUpdate_ = ATOMIC_FLAG_INIT;
+    mutable std::mutex lockCurrentProxyInfos_;
     NodeStatus statusIpv4_ {NodeStatus::Disconnected};
     NodeStatus statusIpv6_ {NodeStatus::Disconnected};
     NodeStats stats4_ {};
@@ -340,8 +341,9 @@ private:
     std::vector<std::function<void()>> callbacks_;
     std::mutex lockCallbacks;
 
+    Sp<InfoState> infoState_;
     std::thread statusThread_;
-    mutable std::mutex lockCurrentProxyInfos_;
+    mutable std::mutex statusLock_;
 
     Scheduler scheduler;
     /**
@@ -349,6 +351,8 @@ private:
      */
     void confirmProxy();
     Sp<Scheduler::Job> nextProxyConfirmation {};
+    Sp<Scheduler::Job> listenerRestart {};
+
     /**
      * Relaunch LISTEN requests if the client disconnect/reconnect.
      */
@@ -373,7 +377,7 @@ private:
     void getPushRequest(Json::Value&) const;
 #endif // OPENDHT_PUSH_NOTIFICATIONS
 
-    bool isDestroying_ {false};
+    std::atomic_bool isDestroying_ {false};
 };
 
 }
